@@ -26,7 +26,7 @@ def test_set_http_password(
 ) -> None:
     manager = PasswordManager(config)
 
-    assert manager.keyring.is_available()
+    assert PoetryKeyring.is_available()
     manager.set_http_password("foo", "bar", "baz")
 
     assert dummy_keyring.get_password("poetry-repository-foo", "bar") == "baz"
@@ -43,7 +43,7 @@ def test_get_http_auth(
     config.auth_config_source.add_property("http-basic.foo", {"username": "bar"})
     manager = PasswordManager(config)
 
-    assert manager.keyring.is_available()
+    assert PoetryKeyring.is_available()
     auth = manager.get_http_auth("foo")
     assert auth is not None
 
@@ -58,7 +58,7 @@ def test_delete_http_password(
     config.auth_config_source.add_property("http-basic.foo", {"username": "bar"})
     manager = PasswordManager(config)
 
-    assert manager.keyring.is_available()
+    assert PoetryKeyring.is_available()
     manager.delete_http_password("foo")
 
     assert dummy_keyring.get_password("poetry-repository-foo", "bar") is None
@@ -70,7 +70,7 @@ def test_set_pypi_token(
 ) -> None:
     manager = PasswordManager(config)
 
-    assert manager.keyring.is_available()
+    assert PoetryKeyring.is_available()
     manager.set_pypi_token("foo", "baz")
 
     assert config.get("pypi-token.foo") is None
@@ -84,7 +84,7 @@ def test_get_pypi_token(
     dummy_keyring.set_password("poetry-repository-foo", "__token__", "baz")
     manager = PasswordManager(config)
 
-    assert manager.keyring.is_available()
+    assert PoetryKeyring.is_available()
     assert manager.get_pypi_token("foo") == "baz"
 
 
@@ -94,7 +94,7 @@ def test_delete_pypi_token(
     dummy_keyring.set_password("poetry-repository-foo", "__token__", "baz")
     manager = PasswordManager(config)
 
-    assert manager.keyring.is_available()
+    assert PoetryKeyring.is_available()
     manager.delete_pypi_token("foo")
 
     assert dummy_keyring.get_password("poetry-repository-foo", "__token__") is None
@@ -105,7 +105,7 @@ def test_set_http_password_with_unavailable_backend(
 ) -> None:
     manager = PasswordManager(config)
 
-    assert not manager.keyring.is_available()
+    assert not PoetryKeyring.is_available()
     manager.set_http_password("foo", "bar", "baz")
 
     auth = config.get("http-basic.foo")
@@ -121,7 +121,7 @@ def test_get_http_auth_with_unavailable_backend(
     )
     manager = PasswordManager(config)
 
-    assert not manager.keyring.is_available()
+    assert not PoetryKeyring.is_available()
     auth = manager.get_http_auth("foo")
     assert auth is not None
 
@@ -137,7 +137,7 @@ def test_delete_http_password_with_unavailable_backend(
     )
     manager = PasswordManager(config)
 
-    assert not manager.keyring.is_available()
+    assert not PoetryKeyring.is_available()
     manager.delete_http_password("foo")
 
     assert config.get("http-basic.foo") is None
@@ -148,7 +148,7 @@ def test_set_pypi_token_with_unavailable_backend(
 ) -> None:
     manager = PasswordManager(config)
 
-    assert not manager.keyring.is_available()
+    assert not PoetryKeyring.is_available()
     manager.set_pypi_token("foo", "baz")
 
     assert config.get("pypi-token.foo") == "baz"
@@ -160,7 +160,7 @@ def test_get_pypi_token_with_unavailable_backend(
     config.auth_config_source.add_property("pypi-token.foo", "baz")
     manager = PasswordManager(config)
 
-    assert not manager.keyring.is_available()
+    assert not PoetryKeyring.is_available()
     assert manager.get_pypi_token("foo") == "baz"
 
 
@@ -170,7 +170,7 @@ def test_delete_pypi_token_with_unavailable_backend(
     config.auth_config_source.add_property("pypi-token.foo", "baz")
     manager = PasswordManager(config)
 
-    assert not manager.keyring.is_available()
+    assert not PoetryKeyring.is_available()
     manager.delete_pypi_token("foo")
 
     assert config.get("pypi-token.foo") is None
@@ -179,7 +179,7 @@ def test_delete_pypi_token_with_unavailable_backend(
 def test_keyring_raises_errors_on_keyring_errors(
     mocker: MockerFixture, with_fail_keyring: None
 ) -> None:
-    mocker.patch("poetry.utils.password_manager.PoetryKeyring._check")
+    mocker.patch("poetry.utils.password_manager.PoetryKeyring.is_available")
 
     key_ring = PoetryKeyring("poetry")
     with pytest.raises(PoetryKeyringError):
@@ -281,11 +281,11 @@ def test_get_http_auth_does_not_call_keyring_when_credentials_in_environment_var
     os.environ["POETRY_HTTP_BASIC_FOO_PASSWORD"] = "baz"
 
     manager = PasswordManager(config)
-    manager._keyring = MagicMock()
+    manager.keyring = MagicMock()
 
     auth = manager.get_http_auth("foo")
     assert auth == {"username": "bar", "password": "baz"}
-    manager._keyring.get_password.assert_not_called()
+    manager.keyring.get_password.assert_not_called()
 
 
 def test_get_http_auth_does_not_call_keyring_when_password_in_environment_variables(
@@ -299,11 +299,11 @@ def test_get_http_auth_does_not_call_keyring_when_password_in_environment_variab
     os.environ["POETRY_HTTP_BASIC_FOO_PASSWORD"] = "baz"
 
     manager = PasswordManager(config)
-    manager._keyring = MagicMock()
+    manager.keyring = MagicMock()
 
     auth = manager.get_http_auth("foo")
     assert auth == {"username": "bar", "password": "baz"}
-    manager._keyring.get_password.assert_not_called()
+    manager.keyring.get_password.assert_not_called()
 
 
 def test_get_pypi_token_with_env_var_positive(
@@ -332,3 +332,40 @@ def test_get_pypi_token_with_env_var_not_available(
     result_token = manager.get_pypi_token(repo_name)
 
     assert result_token is None
+
+
+def test_disabled_keyring_never_called(
+    config: Config, with_simple_keyring: None, dummy_keyring: DummyBackend
+) -> None:
+    config.config["keyring"]["enabled"] = False
+    config.config["http-basic"] = {"onlyuser": {"username": "user"}}
+
+    manager = PasswordManager(config)
+    num_public_functions = len([f for f in dir(manager) if not f.startswith("_")])
+    if num_public_functions != 10:
+        pytest.fail(
+            f"A function was added to or removed from the {PasswordManager.__name__} "
+            "class without reflecting this change in this test."
+        )
+
+    with pytest.raises(PoetryKeyringError) as e:
+        _ = manager.keyring
+
+    assert str(e.value) == "Access to keyring was requested, but it is not available"
+
+    # We made sure that accessing a disabled keyring raises an exception.
+    # Now we call the PasswordManager functions that do access the keyring to
+    # make sure that they never do so when the keyring is disabled.
+    manager.set_pypi_token(repo_name="exists", token="token")
+    manager.get_pypi_token(repo_name="exists")
+    manager.get_pypi_token(repo_name="doesn't exist")
+    manager.delete_pypi_token(repo_name="exists")
+    manager.delete_pypi_token(repo_name="doesn't exist")
+    manager.set_http_password(repo_name="exists", username="user", password="password")
+    manager.get_http_auth(repo_name="exists")
+    manager.get_http_auth(repo_name="doesn't exist")
+    manager.get_http_auth(repo_name="onlyuser")
+    manager.delete_http_password(repo_name="exits")
+    manager.delete_http_password(repo_name="doesn't exist")
+    manager.delete_http_password(repo_name="onlyuser")
+    manager.get_credential("a", "b", "c", username="user")
